@@ -19,6 +19,11 @@ for template in $(find -name '*.tpl'); do
 	mv $template.new $template
 done
 
+for class in $(find -name 'class_*.inc'); do
+	sed -e 's/\($pl[DH][^=]*\)= *"\([^"]*\)";$/\1= _("\2");/g' $class > $class.new
+	mv $class.new $class
+done
+
 echo "Converting strings from gosa.conf"
 sed -e 's/headline="\([^"]*\)"/<?php $headline=_("\1");?>/g;s/name="\([^"]*\)"/<?php $t= _("\1");?>/g' contrib/gosa.conf > contrib/gosa.conf.new
 mv contrib/gosa.conf.new contrib/gosa.conf
