@@ -21,6 +21,10 @@ function keyDown(DnEvents) {
   }
 }
 
+function changeState(myField) {
+  document.getElementById(myField).disabled=(document.getElementById(myField).disabled)?false:true;
+}
+
 document.onkeydown= keyDown; // work together to analyze keystrokes
 if (netscape){
   document.captureEvents(Event.KEYDOWN|Event.KEYUP);
